@@ -25,6 +25,14 @@ __PACKAGE__->setup();
         $c->res->body($c->res->body().$arg);
     }
     
+    sub subtest_params : Global {
+        my ( $self, $c ) = @_;
+        my $before = $c->req->params->{value};
+        my $subreq = $c->subreq('/normal/2');
+        my $after = $c->req->params->{value};
+        $c->res->body($c->res->body().$after);
+    }
+
     sub end : Private {
         my ( $self, $c ) = @_;
         $c->res->body($c->res->body().'3');
